Changelog
=========

0.6 (2017-07-19)
----------------

 * Don't stick Pyramid to version 1.5


0.5 (2015-06-16)
----------------

 * Minified in gzip the response if possible


0.4 (2015-06-30)
----------------

 * Minified exceptions renderered pages too


0.3 (2015-01-21)
----------------

 * don't raise when the content type response is not set.


0.2 (2014-10-20)
----------------

 * minify options are now configurable via Pyramid settings.


0.1 (2014-10-13)
----------------

 * Initial version.
